@@ -29,11 +29,11 @@ logger = logging.getLogger(__name__)
 
 def find_resource(manager, name_or_id):
     """Helper for the _find_* methods."""
-
     # first try the entity as a string
     try:
         return manager.get(name_or_id)
-    except (exceptions.NotFound):
+    except (exceptions.NotFound):  # nosec(cjschaef): try to find 'name_or_id'
+        # as a six.binary_type instead
         pass
 
     # finally try to find entity by name
@@ -53,7 +53,7 @@ def find_resource(manager, name_or_id):
 
 
 def unauthenticated(f):
-    """Adds 'unauthenticated' attribute to decorated function.
+    """Add 'unauthenticated' attribute to decorated function.
 
     Usage::
 
@@ -83,7 +83,7 @@ def hash_signed_token(signed_text, mode='md5'):
 
 
 def prompt_user_password():
-    """Prompt user for a password
+    """Prompt user for a password.
 
     Prompt for a password if stdin is a tty.
     """
@@ -94,7 +94,8 @@ def prompt_user_password():
         # Check for Ctl-D
         try:
             password = getpass.getpass('Password: ')
-        except EOFError:
+        except EOFError:  # nosec(cjschaef): return password, which is None if
+            # password was not found
             pass
 
     return password
@@ -126,7 +127,6 @@ _ISO8601_TIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
 
 def isotime(at=None, subsecond=False):
     """Stringify time in ISO 8601 format."""
-
     # Python provides a similar instance method for datetime.datetime objects
     # called isoformat(). The format of the strings generated by isoformat()
     # have a couple of problems:
@@ -138,7 +138,6 @@ def isotime(at=None, subsecond=False):
     #    the value happens to be 0. This will likely show up as random failures
     #    as parsers may be written to always expect microseconds, and it will
     #    parse correctly most of the time.
-
     if not at:
         at = timeutils.utcnow()
     st = at.strftime(_ISO8601_TIME_FORMAT
